==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-kbindicator/kbindicator.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="17"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="20"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="24"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="26"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="31"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="33"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="63"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="63"/>
        <source>Variant</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard indicator settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>LEDs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="74"/>
        <source>Show keyboard layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="99"/>
        <source>Show flags instead labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="106"/>
        <source>Layout mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="116"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="129"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="142"/>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="152"/>
        <source>Configure layouts...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-kbindicator/kbindicator.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
